======
Struct
======

The following methods are available under the `Series.struct` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Series.struct.field
    Series.struct.rename_fields
    Series.struct.unnest

.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_attribute.rst

    Series.struct.fields
    Series.struct.schema
